aboutsummaryrefslogtreecommitdiff
path: root/module/zfs/spa_config.c
diff options
context:
space:
mode:
authorMatthew Ahrens <mahrens@delphix.com>2016-09-22 16:30:13 +0000
committerBrian Behlendorf <behlendorf1@llnl.gov>2018-04-14 19:16:17 +0000
commita1d477c24c7badc89c60955995fd84d311938486 (patch)
treed0efeec0908cd74a183e1d1975244c951226c4fb /module/zfs/spa_config.c
parent4b0f5b2d7b99ca3ed9585173fe4b1c7fedda5aa5 (diff)
downloadsrc-a1d477c24c7badc89c60955995fd84d311938486.tar.gz
src-a1d477c24c7badc89c60955995fd84d311938486.zip
Diffstat (limited to 'module/zfs/spa_config.c')
-rw-r--r--module/zfs/spa_config.c11
1 files changed, 6 insertions, 5 deletions
diff --git a/module/zfs/spa_config.c b/module/zfs/spa_config.c
index ec9661b86ebc..4e9fd6c575ff 100644
--- a/module/zfs/spa_config.c
+++ b/module/zfs/spa_config.c
@@ -55,7 +55,7 @@
* configuration information. When the module loads, we read this information
* from /etc/zfs/zpool.cache and populate the SPA namespace. This namespace is
* maintained independently in spa.c. Whenever the namespace is modified, or
* the configuration of a pool is changed, we call spa_config_sync(), which
* walks through all the active pools and writes the configuration to disk.
*/
@@ -249,7 +249,7 @@ spa_config_write(spa_config_dirent_t *dp, nvlist_t *nvl)
* would be required.
*/
void
-spa_config_sync(spa_t *target, boolean_t removing, boolean_t postsysevent)
+spa_write_cachefile(spa_t *target, boolean_t removing, boolean_t postsysevent)
{
spa_config_dirent_t *dp, *tdp;
nvlist_t *nvl;
@@ -590,15 +590,16 @@ spa_config_update(spa_t *spa, int what)
/*
* Update the global config cache to reflect the new mosconfig.
*/
- if (!spa->spa_is_root)
- spa_config_sync(spa, B_FALSE, what != SPA_CONFIG_UPDATE_POOL);
+ if (!spa->spa_is_root) {
+ spa_write_cachefile(spa, B_FALSE,
+ what != SPA_CONFIG_UPDATE_POOL);
+ }
if (what == SPA_CONFIG_UPDATE_POOL)
spa_config_update(spa, SPA_CONFIG_UPDATE_VDEVS);
}
#if defined(_KERNEL) && defined(HAVE_SPL)
-EXPORT_SYMBOL(spa_config_sync);
EXPORT_SYMBOL(spa_config_load);
EXPORT_SYMBOL(spa_all_configs);
EXPORT_SYMBOL(spa_config_set);
@@ -55,7 +55,7 @@
* from /etc/zfs/zpool.cache and populate the SPA namespace. This namespace is
* maintained independently in spa.c. Whenever the namespace is modified, or
- * the configuration of a pool is changed, we call spa_config_sync(), which
+ * the configuration of a pool is changed, we call spa_write_cachefile(), which
* walks through all the active pools and writes the configuration to disk.
*/